dnl as-db-doc.m4
dnl
dnl $Id: as-db-doc.m4,v 1.14 2004/04/19 23:16:55 thomas Exp $
dnl add this file using cvs -ko to retain this header

dnl arguments:
dnl - docbook output formats to check
dnl
dnl sets "DB_OUTPUT_FORMATS", a global variable
AC_DEFUN([AS_DB_SET_OUTPUT_FORMATS], [
  DB_OUTPUT_FORMATS=$1
  
  for format in $DB_OUTPUT_FORMATS;
  do
    AC_MSG_NOTICE(Checking for tools needed to generate $format)
    case $format in
      html) AS_DB_CHECK_HTML(HAVE_FORMAT_HTML="yes", [
              AC_MSG_WARN(Cannot generate HTML documentation)
              HAVE_FORMAT_HTML="no"
            ]) ;;
      pdf)  AS_DB_CHECK_PDF(HAVE_FORMAT_PDF="yes", [
              AC_MSG_WARN(Cannot generate PDF documentation)
              HAVE_FORMAT_PDF="no"
            ]) ;;
      ps)   AS_DB_CHECK_PS(HAVE_FORMAT_PS="yes", [
              AC_MSG_WARN(Cannot generate PS documentation)
              HAVE_FORMAT_PS="no"
            ]) ;;
      txt)  AS_DB_CHECK_TXT(HAVE_FORMAT_TXT="yes", [
              AC_MSG_WARN(Cannot generate text documentation)
              HAVE_FORMAT_TXT="no"
            ]) ;;
      *)    AC_MSG_ERROR(Unknown format $format) ;;
    esac
  done
  
  dnl make our decision known to automake
  AM_CONDITIONAL(HAVE_FORMAT_HTML, test "x$HAVE_FORMAT_HTML" = "xyes")
  AM_CONDITIONAL(HAVE_FORMAT_PDF, test "x$HAVE_FORMAT_PDF" = "xyes")
  AM_CONDITIONAL(HAVE_FORMAT_PS, test "x$HAVE_FORMAT_PS" = "xyes")
  AM_CONDITIONAL(HAVE_FORMAT_TXT, test "x$HAVE_FORMAT_TXT" = "xyes")
])

dnl macro to generate a temporary Docbook/XML file
dnl arguments:
dnl - variable name to store temporary file name in
dnl - docbook version to check
dnl creates a temporary file which needs to be cleaned up
AC_DEFUN([AS_DB_TMP_XML],[
  $1=`mktemp /tmp/xml.XXXXXXXX`
  DBVER=$2

  cat <<EOF > $$1
<?xml version='1.0'?>
<!DOCTYPE article PUBLIC "-//OASIS//DTD DocBook XML V$DBVER//EN"
          "http://www.oasis-open.org/docbook/xml/$DBVER/docbookx.dtd" [
]>
<article>
  <para>
    We need some text or we won't get dvi output.
  </para>
</article>
EOF
])

dnl Check if we can use xlmto to generate a given type of documentation
dnl arguments:
dnl - type of documentation, as accepted by xmlto
dnl - DocBook version
dnl - code to execute in case of success
dnl - code to execute in case of failure
AC_DEFUN([AS_DB_CHECK_XMLTO], [
  FORMAT=$1
  DBVER=$2
  
  AC_CHECK_PROG(HAVE_XMLTO, xmlto, yes, no)
  AS_DB_TMP_XML(TMPFILE, $DBVER)
  TMPDIR=`mktemp -d /tmp/xmlto.XXXXXXXX`
  AC_MSG_CHECKING([whether we can process a test DocBook $DBVER XML file to $FORMAT])
  xmlto $FORMAT -o ${TMPDIR} ${TMPFILE} > /dev/null 2>&1
  
  dnl determine the output filename we want to check for
  dnl for ps and pdf, it uses the before-dot-part of the input name, ie. xml
  case $FORMAT in
      pdf)  OUTFILE=${TMPDIR}/xml.pdf ;;
      ps)   OUTFILE=${TMPDIR}/xml.ps ;;
      html) OUTFILE=${TMPDIR}/index.html ;;
      txt)  OUTFILE=${TMPDIR}/xml.txt ;;
      *) AC_MSG_ERROR(Unknown format $FORMAT) ;;
  esac
  
  if test -e $OUTFILE
  then
    ifelse([$3], , :, [$3])
  else
    ifelse([$4], , :, [$4])
  fi
  
  rm ${TMPFILE}
  rm -rf ${TMPDIR}
])


dnl Check if we can generate HTML documentation
dnl arguments:
dnl - code to execute in case of success
dnl - code to execute in case of failure
AC_DEFUN([AS_DB_CHECK_HTML], [
  
  AS_DB_CHECK_XMLTO(html, 4.2, HAVE_XMLTO_HTML="yes", HAVE_XMLTO_HTML="no")
  AC_MSG_RESULT([$HAVE_XMLTO_HTML])
  
  if test "x$HAVE_XMLTO_HTML" = "xyes"
  then
    ifelse([$1], , :, [$1])
  else
    ifelse([$2], , :, [$2])
  fi
])

dnl Check if we can generate PDF documentation
dnl arguments:
dnl - code to execute in case of success
dnl - code to execute in case of failure
AC_DEFUN([AS_DB_CHECK_PDF], [
  
  AS_DB_CHECK_XMLTO(pdf, 4.2, HAVE_XMLTO_PDF="yes", HAVE_XMLTO_PDF="no")
  AC_MSG_RESULT([$HAVE_XMLTO_PDF])
  
  if test "x$HAVE_XMLTO_PDF" = "xyes"
  then
    ifelse([$1], , :, [$1])
  else
    ifelse([$2], , :, [$2])
  fi
])

dnl Check if we can generate PDF documentation
dnl arguments:
dnl - code to execute in case of success
dnl - code to execute in case of failure
AC_DEFUN([AS_DB_CHECK_PS], [
  
  AS_DB_CHECK_XMLTO(ps, 4.2, HAVE_XMLTO_PS="yes", HAVE_XMLTO_PS="no")
  AC_MSG_RESULT([$HAVE_XMLTO_PS])
  
  if test "x$HAVE_XMLTO_PS" = "xyes"
  then
    ifelse([$1], , :, [$1])
  else
    ifelse([$2], , :, [$2])
  fi
])

dnl Check if we can generate TXT documentation
dnl arguments:
dnl - code to execute in case of success
dnl - code to execute in case of failure
AC_DEFUN([AS_DB_CHECK_TXT], [
  
  AS_DB_CHECK_XMLTO(txt, 4.2, HAVE_XMLTO_TXT="yes", HAVE_XMLTO_TXT="no")
  AC_MSG_RESULT([$HAVE_XMLTO_TXT])
  
  if test "x$HAVE_XMLTO_TXT" = "xyes"
  then
    ifelse([$1], , :, [$1])
  else
    ifelse([$2], , :, [$2])
  fi
])
