dnl as-db-img.m4
dnl
dnl $Id: as-db-images.m4,v 1.11 2004/04/19 22:46:00 thomas Exp $
dnl add this file using cvs -ko to retain this header

dnl all macros concerning image generation

dnl set the image formats we want to build from
dnl this variable is used globally
AC_DEFUN([AS_DB_SET_IMAGE_FORMATS], [
  DB_IMAGE_FORMATS="$1"
])

dnl fig2dev output format check
dnl checks if the given output format is supported by fig2dev
dnl executes second argument if supported, third if not supported.
AC_DEFUN([AS_DB_CHECK_FIG2DEV_OUTPUT], [
  FORMAT=$1
  
  dnl check if we have fig2dev
  AC_CHECK_PROG(HAVE_FIG2DEV, fig2dev, yes, no)
  if test "x$HAVE_FIG2DEV" = "xno";
  then
    AC_MSG_ERROR([Did not find fig2dev (transfig), cannot generate images.])
  else
    AC_MSG_CHECKING([whether fig2dev supports output to $FORMAT])
    fig2dev_quiet=`fig2dev -L [$1] </dev/null 2>&1 >/dev/null`
    if test "x$fig2dev_quiet" = "x";
    then
      AC_MSG_RESULT([yes])
      ifelse([$2], , :, [$2])
    else
      AC_MSG_RESULT([no])
      ifelse([$3], , :, [$3])
    fi
  fi
])

dnl *** a slew of specific image format conversion checks
dnl checks if we can do the given conversion
 
dnl check if we can convert .fig to .pdf
dnl fig -> ps needs transfig and ghostscript
AC_DEFUN([AS_DB_CHECK_FIG_TO_PDF], [
  
  AC_MSG_NOTICE([Checking for tools needed to generate .pdf from .fig])
  dnl innocent until proven guilty
  HAVE_FIG_TO_PDF=yes
  
  AC_CHECK_PROG(HAVE_GS, gs, yes, no)
  if test "x$HAVE_GS" = "xno"
  then
    HAVE_FIG_TO_PDF=no
  else
    AS_DB_CHECK_FIG2DEV_OUTPUT(eps, HAVE_FIG_TO_PDF=yes)
  fi
  
  if test "x$HAVE_FIG_TO_PDF" = "xyes"
  then
    ifelse([$1], , :, [$1])
  else
    ifelse([$2], , :, [$2])
  fi
])

dnl check if we can convert .fig to .ps(EPS)
dnl fig -> ps needs transfig and ghostscript
dnl define an automake conditional
AC_DEFUN([AS_DB_CHECK_FIG_TO_PS], [
  
  AC_MSG_NOTICE([Checking for tools needed to generate .ps(EPS) from .fig])
  dnl innocent until proven guilty
  HAVE_FIG_TO_PS=yes
  
  AC_CHECK_PROG(HAVE_GS, gs, yes, no)
  if test "x$HAVE_GS" = "xno"
  then
    HAVE_FIG_TO_PS=no
  else
    AS_DB_CHECK_FIG2DEV_OUTPUT(eps, HAVE_FIG_TO_PS=yes)
  fi
  
  if test "x$HAVE_FIG_TO_PS" = "xyes"
  then
    ifelse([$1], , :, [$1])
  else
    ifelse([$2], , :, [$2])
  fi
])

dnl check if we can convert .fig to .png
dnl fig -> png needs transfig and ghostscript
dnl define an automake conditional
AC_DEFUN([AS_DB_CHECK_FIG_TO_PNG], [
  
  AC_MSG_NOTICE([Checking for tools needed to generate .png from .fig])
  dnl innocent until proven guilty
  HAVE_FIG_TO_PNG=yes
  
  AC_CHECK_PROG(HAVE_GS, gs, yes, no)
  if test "x$HAVE_GS" = "xno"
  then
    HAVE_FIG_TO_PNG=no
  else
    AS_DB_CHECK_FIG2DEV_OUTPUT(png, HAVE_FIG_TO_PNG=yes)
  fi
  
  if test "x$HAVE_FIG_TO_PNG" = "xyes"
  then
    ifelse([$1], , :, [$1])
  else
    ifelse([$2], , :, [$2])
  fi
])

dnl check if we can convert .png to .pdf
dnl png -> ps needs pngtopnm, pnmtops (netpbm-progs) and epstopdf (tetex)
dnl define an automake conditional
AC_DEFUN([AS_DB_CHECK_PNG_TO_PDF], [
  
  AC_MSG_NOTICE([Checking for tools needed to generate .pdf from .png])
  dnl innocent until proven guilty
  HAVE_PNG_TO_PDF=yes
  
  AC_CHECK_PROG(HAVE_PNGTOPNM, pngtopnm, yes, no)
  AC_CHECK_PROG(HAVE_PNMTOPS, pnmtops, yes, no)
  AC_CHECK_PROG(HAVE_EPSTOPDF, epstopdf, yes, no)
  if test "x$HAVE_PNGTOPNM" = "xno" ||
     test "x$HAVE_PNMTOPS" = "xno" ||
     test "x$HAVE_EPSTOPDF" = "xno"
  then
    HAVE_PNG_TO_PDF=no
  fi
  
  if test "x$HAVE_PNG_TO_PDF" = "xyes"
  then
    ifelse([$1], , :, [$1])
  else
    ifelse([$2], , :, [$2])
  fi
])

dnl check if we can convert .png to .ps
dnl png -> ps needs pngtopnm, pnmtops (netpbm-progs)
dnl define an automake conditional
AC_DEFUN([AS_DB_CHECK_PNG_TO_PS], [
  
  AC_MSG_NOTICE([Checking for tools needed to generate .ps from .png])
  dnl innocent until proven guilty
  HAVE_PNG_TO_PS=yes
  
  AC_CHECK_PROG(HAVE_PNGTOPNM, pngtopnm, yes, no)
  AC_CHECK_PROG(HAVE_PNMTOPS, pnmtops, yes, no)
  if test "x$HAVE_PNGTOPNM" = "xno" ||
     test "x$HAVE_PNMTOPS" = "xno"
  then
    HAVE_PNG_TO_PS=no
  fi
  
  if test "x$HAVE_PNG_TO_PS" = "xyes"
  then
    ifelse([$1], , :, [$1])
  else
    ifelse([$2], , :, [$2])
  fi
])

dnl check if we can convert .ps to .pdf
dnl png -> ps needs epstopdf (tetex)
dnl define an automake conditional
AC_DEFUN([AS_DB_CHECK_PS_TO_PDF], [
  
  AC_MSG_NOTICE([Checking for tools needed to generate .pdf from .ps])
  dnl innocent until proven guilty
  HAVE_PS_TO_PDF=yes
  
  AC_CHECK_PROG(HAVE_EPSTOPDF, epstopdf, yes, no)
  if test "x$HAVE_EPSTOPDF" = "xno"
  then
    HAVE_PS_TO_PDF=no
  fi
  
  if test "x$HAVE_PS_TO_PDF" = "xyes"
  then
    ifelse([$1], , :, [$1])
  else
    ifelse([$2], , :, [$2])
  fi
])

dnl check if we can convert .ps to .png
dnl png -> ps needs pstopnm, pnmtopng (netpbm-progs)
dnl define an automake conditional
AC_DEFUN([AS_DB_CHECK_PS_TO_PNG], [
  
  AC_MSG_NOTICE([Checking for tools needed to generate .png from .ps])
  dnl innocent until proven guilty
  HAVE_PS_TO_PNG=yes
  
  AC_CHECK_PROG(HAVE_PSTOPNM, pstopnm, yes, no)
  AC_CHECK_PROG(HAVE_PNMTOPNG, pnmtopng, yes, no)
  if test "x$HAVE_PSTOPNM" = "xno" ||
     test "x$HAVE_PNMTOPNG" = "xno"
  then
    HAVE_PS_TO_PNG=no
  fi
  
  if test "x$HAVE_PS_TO_PNG" = "xyes"
  then
    ifelse([$1], , :, [$1])
  else
    ifelse([$2], , :, [$2])
  fi
])

dnl check for all the image tools we need
dnl this uses two variables from previous macros:
dnl AS_DB_OUTPUT_FORMATS
dnl AS_DB_IMAGE_FORMATS
dnl FIXME: but not yet
AC_DEFUN([AS_DB_CHECK_IMAGE], [
  
  dnl all conversions are guilty until proven innocent
  HAVE_FIG_TO_PDF=no
  HAVE_FIG_TO_PNG=no
  HAVE_FIG_TO_PS=no
  HAVE_PNG_TO_PDF=no
  HAVE_PNG_TO_PS=no
  HAVE_PS_TO_PDF=no
  HAVE_PS_TO_PNG=no
  
  dnl possible image conversion is innocent until proven guilty
  IMAGE=yes
  for imageformat in $DB_IMAGE_FORMATS
  do
    case $imageformat in
      fig)
        for outputformat in $DB_OUTPUT_FORMATS
        do
          case $outputformat in
            html) AS_DB_CHECK_FIG_TO_PNG(HAVE_FIG_TO_PNG=yes, IMAGE=no) ;;
            pdf)  AS_DB_CHECK_FIG_TO_PDF(HAVE_FIG_TO_PDF=yes, IMAGE=no) ;;
            ps)   AS_DB_CHECK_FIG_TO_PS(HAVE_FIG_TO_PS=yes, IMAGE=no) ;;
            txt)  ;;
            *)    AC_MSG_ERROR(Unknown output format $outputformat) ;;
          esac
        done
        ;;
      png)
        for outputformat in $DB_OUTPUT_FORMATS
        do
          case $outputformat in
            html) ;;
            pdf)  AS_DB_CHECK_PNG_TO_PDF(HAVE_PNG_TO_PDF=yes, IMAGE=no) ;;
            ps)   AS_DB_CHECK_PNG_TO_PS(HAVE_PNG_TO_PS=yes, IMAGE=no) ;;
            txt)  ;;
            *)    AC_MSG_ERROR(Unknown output format $outputformat) ;;
          esac
        done
        ;;
      ps)
        for outputformat in $DB_OUTPUT_FORMATS
        do
          case $outputformat in
            html)   AS_DB_CHECK_PS_TO_PNG(HAVE_PS_TO_PNG=yes, IMAGE=no) ;;
            pdf)  AS_DB_CHECK_PS_TO_PDF(HAVE_PS_TO_PDF=yes, IMAGE=no) ;;
            ps) ;;
            txt)  ;;
            *)    AC_MSG_ERROR(Unknown output format $outputformat) ;;
          esac
        done
        ;;
       *) AC_MSG_ERROR(Unknown image source format $imageformat) ;;
    esac
  done
  
  dnl set all automake conditionals
  AM_CONDITIONAL(HAVE_FIG_TO_PDF, test "x$HAVE_FIG_TO_PDF" = "xyes")
  AM_CONDITIONAL(HAVE_FIG_TO_PNG, test "x$HAVE_FIG_TO_PNG" = "xyes")
  AM_CONDITIONAL(HAVE_FIG_TO_PS, test "x$HAVE_FIG_TO_PS" = "xyes")
  AM_CONDITIONAL(HAVE_PNG_TO_PDF, test "x$HAVE_PNG_TO_PDF" = "xyes")
  AM_CONDITIONAL(HAVE_PNG_TO_PS, test "x$HAVE_PNG_TO_PS" = "xyes")
  AM_CONDITIONAL(HAVE_PS_TO_PDF, test "x$HAVE_PS_TO_PDF" = "xyes")
  AM_CONDITIONAL(HAVE_PS_TO_PNG, test "x$HAVE_PS_TO_PNG" = "xyes")
  
  if test "x$IMAGE" = "xyes"
  then
    ifelse([$1], , :, [$1])
  else
    ifelse([$2], , :, [$2])
  fi
])
