# doc.mak
#
# $Id: doc.mak,v 1.14 2004/04/19 23:31:11 thomas Exp $
# add this file using cvs -ko to retain this header

# data targets to generate; requires DOC to be defined higher up
if HAVE_FORMAT_PDF
PDF_DAT = $(DOC).pdf
else
PDF_DAT =
endif

if HAVE_FORMAT_PS
PS_DAT = $(DOC).ps
else
PS_DAT =
endif

if HAVE_FORMAT_TXT
TXT_DAT = $(DOC).txt
else
TXT_DAT =
endif


# since html output really is a subtree of stuff in html/, we have to hook
# in local install/uninstall rules
if HAVE_FORMAT_HTML
install-data-local: html
	@echo Installing HTML documentation
	$(mkinstalldirs) $(DESTDIR)$(docdir)
	cp -pr html $(DESTDIR)$(docdir)
                                                                                
uninstall-local:
	@echo Uninstalling HTML documentation
	@for part in html; do rm -rf $(DESTDIR)$(docdir)/$$part; done
	@if test -d $(DESTDIR)$(docdir); then rmdir $(DESTDIR)$(docdir) > /dev/null 2>&1 || true; fi
all-local: html
else
install-data-local:
uninstall-local:
all-local:
endif

# this can't be named DOC_DATA since then automake picks it up
DOC_DAT = $(PDF_DAT) $(PS_DAT) $(TXT_DAT)

# files that need cleaning from this snippet
CLEANFILES_DOC = $(DOC_DAT)

### rules to generate output data
html/*.html: html

html: $(BUILDDIR)/$(MAIN) $(PNG_BUILT) $(FIG_SRC) $(PS_SRC) $(HTML_XSL)
	@make check-local
	@-mkdir -p html
	@make $(BUILDDIR)/image.entities.png
# copy stylesheets into build dir so we don't have to fiddle with paths
	@if test "x$(HTML_XSL)" != "x"; then \
          for file in $(HTML_XSL); do $(install_sh_DATA) $(srcdir)/$$file $(BUILDDIR); done; \
        fi
# create a command-line option to xmlto for the custom stylesheets
# create a command-line option to use the HTML CSS stylesheet if set
# if there's an HTML_STYLE modifier, use it
# and process
	@for xsl in $(HTML_XSL); do \
          XSL_ARGS="$$XSL_ARGS -m $$xsl"; \
        done; \
        HTML_TARGET=html; \
        if test "x$(HTML_STYLE)" = "xnochunks"; then HTML_TARGET=html-nochunks; fi; \
	echo "*** Generating HTML output ($$HTML_TARGET) ***"; \
        cd $(BUILDDIR) && xmlto $$HTML_TARGET -o ../html $$XSL_ARGS $(MAIN)
# copy html stylesheets over if they are set
	@if test "x$(HTML_CSS)" != "x"; then \
          echo "Copying .css files: $(HTML_CSS)"; \
          cp $(srcdir)/$(HTML_CSS) html; fi
# copy png images
	@if test "x$(PNG)" != "x"; then \
          echo "Copying .png images: $(PNG_BUILT)"; \
          mkdir -p html/images; \
          cp $(PNG_BUILT) html/images; fi

$(DOC).pdf: $(BUILDDIR)/$(MAIN) $(PDF_BUILT) $(PNG_SRC) $(FIG_SRC) $(PS_SRC) $(FO_XSL)
	@make check-local
	@echo "*** Generating PDF output ***"
	@make $(BUILDDIR)/image.entities.pdf
# copy stylesheets into build dir so we don't have to fiddle with paths
	@if test "x$(FO_XSL)" != "x"; then \
          for file in $(FO_XSL); do $(install_sh_DATA) $(srcdir)/$$file $(BUILDDIR); done; \
        fi
	@for xsl in $(FO_XSL); do \
          XSL_ARGS="$$XSL_ARGS -m $$xsl"; \
        done; \
	cd $(BUILDDIR) && xmlto pdf $$XSL_ARGS -o .. $(MAIN)

$(DOC).ps: $(BUILDDIR)/$(MAIN) $(PS_BUILT) $(PNG_SRC) $(FIG_SRC) $(PS_SRC) $(FO_XSL)
	@make check-local
	@echo "*** Generating PS output ***"
	@make $(BUILDDIR)/image.entities.ps
# copy stylesheets into build dir so we don't have to fiddle with paths
# use install_sh_DATA so that we get proper permissions, even during distcheck
	@if test "x$(FO_XSL)" != "x"; then \
          for file in $(FO_XSL); do $(install_sh_DATA) $(srcdir)/$$file $(BUILDDIR); done; \
        fi
	@for xsl in $(FO_XSL); do \
          XSL_ARGS="$$XSL_ARGS -m $$xsl"; \
        done; \
	cd $(BUILDDIR) && xmlto ps $$XSL_ARGS -o .. $(MAIN)
# alternative way of generating ps using docbook2ps
# cd $(BUILDDIR) && docbook2ps -o .. $(MAIN)

### alternative way of generating pdf from ps
#$(DOC).pdf: $(DOC).ps
#	@echo "*** Generating PDF output ***"
#	@ps2pdf $(DOC).ps

$(DOC).txt: $(BUILDDIR)/$(MAIN) $(TXT_XSL)
	@make check-local
	@echo "*** Generating TXT output ***"
	@make $(BUILDDIR)/image.entities.ps
# copy stylesheets into build dir so we don't have to fiddle with paths
# use install_sh_DATA so that we get proper permissions, even during distcheck
	@if test "x$(TXT_XSL)" != "x"; then \
          for file in $(TXT_XSL); do $(install_sh_DATA) $(srcdir)/$$file $(BUILDDIR); done; \
        fi
	@for xsl in $(TXT_XSL); do \
          XSL_ARGS="$$XSL_ARGS -m $$xsl"; \
        done; \
	cd $(BUILDDIR) && xmlto txt $$XSL_ARGS -o .. $(MAIN)

### rules to copy source for docs into the intermediate BUILDDIR
$(BUILDDIR)/$(MAIN): $(XML_SRC) $(HTML_CSS) $(EXTRA_SOURCES)
	@if test "x$(XML_SRC)" = "x"; then echo "Define XML_SRC in Makefile.am"; exit 1; fi
	@-mkdir -p $(BUILDDIR)
	@if test "x$(EXTRA_SOURCES)" != "x"; then for a in $(EXTRA_SOURCES); do cp $(srcdir)/$$a $(BUILDDIR); done; fi
	@for a in $(XML_SRC); do $(install_sh_DATA) $(srcdir)/$$a $(BUILDDIR); done
	@for a in $(HTML_CSS); do $(install_sh_DATA) $(srcdir)/$$a $(BUILDDIR); done
	@if test -f ../version.entities; then $(install_sh_DATA) ../version.entities $(BUILDDIR); fi

### a validation rule, hooked into "make check"
check-local: $(BUILDDIR)/$(MAIN)
	@make $(BUILDDIR)/image.entities.ps
	@cd $(BUILDDIR) && xmllint -noout -valid $(MAIN)
