# images.mak
#
# $Id: images.mak,v 1.10 2004/04/19 22:16:47 thomas Exp $
# add this file using cvs -ko to retain this header

# image generation/manipulation

# requires BUILDDIR to be defined before

# in Makefile.am, declare your image source files using
# PNG_SRC and FIG_SRC

# right now, we only allow .png and .fig as source
# we might add more later if we feel the need

### intermediary build path for images
BUILDDIRIMAGES = $(BUILDDIR)/images

### specification of all the result images, without path
# encapsulated .pdf files can be built from .png or .fig
PDF = $(strip $(FIG_SRC:.fig=.pdf) $(PNG_SRC:.png=.pdf))
# PNG's can be source or built from .fig
PNG = $(strip $(PNG_SRC) $(FIG_SRC:.fig=.png))
# encapsulated .ps files can be built from .png or .fig
PS = $(strip $(FIG_SRC:.fig=.ps) $(PNG_SRC:.png=.ps))

### result images, with path
PDF_BUILT = $(foreach file, $(PDF), $(BUILDDIRIMAGES)/$(file))
PNG_BUILT = $(foreach file, $(PNG), $(BUILDDIRIMAGES)/$(file))
PS_BUILT = $(foreach file, $(PS), $(BUILDDIRIMAGES)/$(file))

### image generation

### PNG

# prefer png as source, then fig, then ps
# copy built png from source png
$(BUILDDIRIMAGES)/%.png: %.png
	@echo "Copying $< to $@"
	@mkdir -p $(BUILDDIRIMAGES)
	@cp $< $@

# make png from fig
$(BUILDDIRIMAGES)/%.png: %.fig
	@echo "Generating $@ from $<"
	@mkdir -p $(BUILDDIRIMAGES)
if HAVE_FIG_TO_PNG
	@fig2dev -Lpng $< $@
else
	@echo Cannot generate .png from .fig
endif

# make png from encapsulated ps
$(BUILDDIRIMAGES)/%.png: %.ps
	@echo "Generating $@ from $<"
	@mkdir -p $(BUILDDIRIMAGES)
	@cat $< | pstopnm | pnmtopng > $@

### PS

# prefer ps as source, then png, then fig
# copy built ps from source ps
$(BUILDDIRIMAGES)/%.ps: %.ps
	@echo "Copying $< to $@"
	@mkdir -p $(BUILDDIRIMAGES)
	@cp $< $@

# make encapsulated ps from fig
$(BUILDDIRIMAGES)/%.ps: %.fig
	@echo "Generating $@ from $<"
	@mkdir -p $(BUILDDIRIMAGES)
	@fig2dev -Leps $< $@

# make encapsulated ps from png, allowing for overrides
# FIXME: do we really still need overrides now that we have the
# PS as source option ?
$(BUILDDIRIMAGES)/%.ps: %.png
	@OVERRIDE=$(<:.png=.ps); \
        if test -f $$OVERRIDE; then \
          echo "Overriding generation of $@ with $$OVERRIDE"; \
          cp $$OVERRIDE $(BUILDDIRIMAGES); \
        else \
	  echo "Generating $@ from $<"; \
	  mkdir -p $(BUILDDIRIMAGES); \
	  cat $< | pngtopnm | pnmtops -nosetpage -noturn > $@ 2> /dev/null; \
        fi

### PDF

# prefer ps as source, then fig, then png

# ghostscript options for better image quality recommended by
# http://www.pstricks.de/pdf/pdf.phtml#graphics
# when converting ps to pdf
EPSTOPDF_GS_OPTIONS="\
 -dAutoFilterColorImages=false \
 -dAutoFilterGrayImages=false \
 -sColorImageFilter=FlateEncode \
 -sGrayImageFilter=FlateEncode \
 -dPDFSETTINGS=/prepress \
 -dUseFlateCompression=true"


# make encapsulated pdf from encapsulated ps
$(BUILDDIRIMAGES)/%.pdf: %.ps
	@echo "Generating $@ from $<"
	@mkdir -p $(BUILDDIRIMAGES)
	@cat $< | epstopdf --filter > $@

# make encapsulated pdf from fig
$(BUILDDIRIMAGES)/%.pdf: %.fig
	@echo "Generating $@ from $<"
	@mkdir -p $(BUILDDIRIMAGES)
	@fig2dev -Lpdf $< $@

# make pdf from png, allowing for overrides
$(BUILDDIRIMAGES)/%.pdf: %.png
	@OVERRIDE=$(<:.png=.pdf); \
        if test -f $$OVERRIDE; then \
          echo "Overriding generation of $@ with $$OVERRIDE"; \
          cp $$OVERRIDE $(BUILDDIRIMAGES); \
        else \
	  echo "Generating $@ from $<"; \
	  mkdir -p $(BUILDDIRIMAGES); \
	  cat $< | pngtopnm | pnmtops -nosetpage -noturn 2> /dev/null | epstopdf --filter > $@ 2> /dev/null; \
        fi

# image.entities file generation
$(BUILDDIR)/image.entities.pdf:
	@echo '<!ENTITY image "pdf">' > $@
	@echo '<!ENTITY IMAGE "EPS">' >> $@
	@mv $@ $(BUILDDIR)/image.entities

$(BUILDDIR)/image.entities.png:
	@echo '<!ENTITY image "png">' > $@
	@echo '<!ENTITY IMAGE "PNG">' >> $@
	@mv $@ $(BUILDDIR)/image.entities

$(BUILDDIR)/image.entities.ps:
	@echo '<!ENTITY image "ps">' > $@
	@echo '<!ENTITY IMAGE "EPS">' >> $@
	@mv $@ $(BUILDDIR)/image.entities
